@@ -5,11 +5,11 @@ import java.util.Iterator;
 /**
 * LFTAnalysis饹LFTʬϤԤΥ饹Ǥ<BR>
 * ޤΥ饹Ѥܥޥȥꥯˤޤν٤н뤳ȤǤޤ
-* @version 1.21
+* @version 1.3.1
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ1112
+* ǽ 2004ǯ1206
 */
 public class LFTAnalysis{
 	
@@ -136,7 +136,7 @@ public class LFTAnalysis{
 * @param baseTeacherMatrix ԤΥޥȥꥯ
 * @exception NotSquareMatrixException ԤΥޥȥꥯǤϤʤ
 */
-	public LFTAnalysis(Matrix baseTeacherMatrix){
+	public LFTAnalysis(ArithmeticMatrix baseTeacherMatrix){
 		BooleanMatrix baseStudentMatrix =
 		new BooleanMatrix(baseTeacherMatrix.getRowLength(), baseTeacherMatrix.getColLength(),
 			baseTeacherMatrix.getRowNameArray(), baseTeacherMatrix.getColNameArray());
@@ -156,7 +156,7 @@ public class LFTAnalysis{
 * @exception NotSquareMatrixException ԤޤϳؽԤΥޥȥꥯǤϤʤ
 * @exception DisagreementMatrixSizeException ԤΥޥȥꥯȳؽԤΥޥȥꥯפʤ
 */
-	public LFTAnalysis(Matrix baseTeacherMatrix, Matrix baseStudentMatrix){
+	public LFTAnalysis(ArithmeticMatrix baseTeacherMatrix, ArithmeticMatrix baseStudentMatrix){
 		
 		//ԤΥޥȥꥯꤹ
 		setTeacherMatrix(baseTeacherMatrix.toBooleanMatrix());
@@ -173,7 +173,7 @@ public class LFTAnalysis{
 * @param value BooleanMatrixѴݤΤ
 * @exception NotSquareMatrixException ԤΥޥȥꥯǤϤʤ
 */
-	public LFTAnalysis(Matrix baseTeacherMatrix, double value){
+	public LFTAnalysis(ArithmeticMatrix baseTeacherMatrix, double value){
 		BooleanMatrix baseStudentMatrix =
 		new BooleanMatrix(baseTeacherMatrix.getRowLength(), baseTeacherMatrix.getColLength(),
 			baseTeacherMatrix.getRowNameArray(), baseTeacherMatrix.getColNameArray());
@@ -194,7 +194,7 @@ public class LFTAnalysis{
 * @exception NotSquareMatrixException ԤޤϳؽԤΥޥȥꥯǤϤʤ
 * @exception DisagreementMatrixSizeException ԤΥޥȥꥯȳؽԤΥޥȥꥯפʤ
 */
-	public LFTAnalysis(Matrix baseTeacherMatrix, Matrix baseStudentMatrix, double value){
+	public LFTAnalysis(ArithmeticMatrix baseTeacherMatrix, ArithmeticMatrix baseStudentMatrix, double value){
 		
 		//ԤΥޥȥꥯꤹ
 		setTeacherMatrix(baseTeacherMatrix.toBooleanMatrix());
@@ -217,9 +217,9 @@ public class LFTAnalysis{
 		
 		//ãޥȥꥯ
 		BooleanMatrix reachTeacherMatrix = new BooleanMatrix();
-		reachTeacherMatrix.MatrixCopy(getReachTeacherMatrix());
+		reachTeacherMatrix.matrixCopy(getReachTeacherMatrix());
 		BooleanMatrix reachStudentMatrix = new BooleanMatrix();
-		reachStudentMatrix.MatrixCopy(getReachStudentMatrix());
+		reachStudentMatrix.matrixCopy(getReachStudentMatrix());
 		
 		//׻ǻѤޥȥꥯ
 		BooleanMatrix resultMatrix = new BooleanMatrix(getElement(), getElement());
@@ -228,7 +228,7 @@ public class LFTAnalysis{
 				
 				//ԤΥޥȥꥯǤ2Ǵ֤˻ޤФǴ֤н
 				if (teacherMatrix.getCell(i, j) == true){
-				pairTeacherMatrix.MatrixCopy(getPairMatrix(reachTeacherMatrix, i, j));
+				pairTeacherMatrix.matrixCopy(getPairMatrix(reachTeacherMatrix, i, j));
 				}
 				
 				//ޤʤн϶
@@ -238,7 +238,7 @@ public class LFTAnalysis{
 				
 				//ؽԤΥޥȥꥯǤ2Ǵ֤˻ޤФǴ֤н
 				if (studentMatrix.getCell(i, j) == true){
-				pairStudentMatrix.MatrixCopy(getPairMatrix(reachStudentMatrix, i, j));
+				pairStudentMatrix.matrixCopy(getPairMatrix(reachStudentMatrix, i, j));
 				}
 				
 				//ޤʤн϶
@@ -247,11 +247,11 @@ public class LFTAnalysis{
 				}
 				
 				//ʬη׻
-				resultMatrix.MatrixCopy(pairTeacherMatrix.getOrMatrix(pairStudentMatrix));
+				resultMatrix.matrixCopy(pairTeacherMatrix.getOrMatrix(pairStudentMatrix));
 				denominator = resultMatrix.getElement() + denominator;
 				
 				//ʬҤη׻
-				resultMatrix.MatrixCopy(pairTeacherMatrix.getAndMatrix(pairStudentMatrix));
+				resultMatrix.matrixCopy(pairTeacherMatrix.getAndMatrix(pairStudentMatrix));
 				numerator = resultMatrix.getElement() + numerator;
 			}
 		}
@@ -276,31 +276,43 @@ public class LFTAnalysis{
 * @param Ij ͭޤλ
 * @param Ik ͭޤν
 * @return ޤξ
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
+* @exception DisagreementMatrixSizeException 2ĤΥޥȥꥯפʤ
 * @exception NotElementException ꤷֹ椬¸ߤʤ
 * @see #getBlendMatrix()
 */
 	private int getBlendEdge(BooleanMatrix baseMatrix, BooleanMatrix compareMatrix, int Ij, int Ik){
-		int value;
-		if (baseMatrix.isMatrixEntityPoint(Ij, Ik) && compareMatrix.isMatrixEntityPoint(Ij, Ik)){
-			if (baseMatrix.getCell(Ij, Ik) == compareMatrix.getCell(Ij, Ik)){
-					if(baseMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE){
-						value = LFT_EDGE_INT_TRUE;
-					}
-					else{
-						value = LFT_EDGE_INT_FALSE;
-					}
-				}
-				else if (baseMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE &&
-					compareMatrix.getCell(Ij, Ik) == LFT_EDGE_FALSE){
-					value = LFT_EDGE_TEACHER;
+		if(baseMatrix.isSquare() && compareMatrix.isSquare()){
+			if (baseMatrix.isSameMatrixSize(compareMatrix)){
+				int value;
+				if (baseMatrix.isMatrixEntityPoint(Ij, Ik) && compareMatrix.isMatrixEntityPoint(Ij, Ik)){
+					if (baseMatrix.getCell(Ij, Ik) == compareMatrix.getCell(Ij, Ik)){
+							if(baseMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE){
+								value = LFT_EDGE_INT_TRUE;
+							}
+							else{
+								value = LFT_EDGE_INT_FALSE;
+							}
+						}
+						else if (baseMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE &&
+							compareMatrix.getCell(Ij, Ik) == LFT_EDGE_FALSE){
+							value = LFT_EDGE_TEACHER;
+						}
+						else{
+							value = LFT_EDGE_STUDENT;
+						}
+					return value;
 				}
 				else{
-					value = LFT_EDGE_STUDENT;
+					throw new NotElementException("point(" + Ij + "," + Ik + ")");
 				}
-			return value;
+			}
+			else{
+				throw new DisagreementMatrixSizeException();
+			}
 		}
 		else{
-			throw new NotElementException("point(" + Ij + "," + Ik + ")");
+			throw new NotSquareMatrixException();
 		}
 	}
 	
@@ -313,32 +325,44 @@ public class LFTAnalysis{
 * @param Ij ͭޤλ
 * @param Ik ͭޤν
 * @return ޤξ
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
+* @exception DisagreementMatrixSizeException 2ĤΥޥȥꥯפʤ
 * @exception NotElementException ꤷֹ椬¸ߤʤ
 * @see #getBlendStringMatrix()
 * @see #getBlendStringMatrix(BooleanMatrix baseMatrix, BooleanMatrix compareMatrix)
 */
 	public String getBlend(BooleanMatrix baseMatrix, BooleanMatrix compareMatrix, int Ij, int Ik){
-		String st;
-		if (baseMatrix.isMatrixEntityPoint(Ij, Ik) && compareMatrix.isMatrixEntityPoint(Ij, Ik)){
-			if (baseMatrix.getCell(Ij,Ik) == compareMatrix.getCell(Ij, Ik)){
-					if(baseMatrix.getCell(Ij,Ik) == LFT_EDGE_TRUE){
-						st = LFT_EDGE_STRING_TRUE;
-					}
-					else{
-						st = LFT_EDGE_STRING_FALSE;
-					}
-				}
-				else if (baseMatrix.getCell(Ij,Ik) == LFT_EDGE_TRUE &&
-					compareMatrix.getCell(Ij,Ik) == LFT_EDGE_FALSE){
-					st = LFT_EDGE_STRING_TEACHER;
+		if(baseMatrix.isSquare() && compareMatrix.isSquare()){
+			if (baseMatrix.isSameMatrixSize(compareMatrix)){
+				String st;
+				if (baseMatrix.isMatrixEntityPoint(Ij, Ik) && compareMatrix.isMatrixEntityPoint(Ij, Ik)){
+					if (baseMatrix.getCell(Ij,Ik) == compareMatrix.getCell(Ij, Ik)){
+							if(baseMatrix.getCell(Ij,Ik) == LFT_EDGE_TRUE){
+								st = LFT_EDGE_STRING_TRUE;
+							}
+							else{
+								st = LFT_EDGE_STRING_FALSE;
+							}
+						}
+						else if (baseMatrix.getCell(Ij,Ik) == LFT_EDGE_TRUE &&
+							compareMatrix.getCell(Ij,Ik) == LFT_EDGE_FALSE){
+							st = LFT_EDGE_STRING_TEACHER;
+						}
+						else{
+							st = LFT_EDGE_STRING_STUDENT;
+						}
+					return st;
 				}
 				else{
-					st = LFT_EDGE_STRING_STUDENT;
+					throw new NotElementException("point(" + Ij + "," + Ik + ")");
 				}
-			return st;
+			}
+			else{
+				throw new DisagreementMatrixSizeException();
+			}
 		}
 		else{
-			throw new NotElementException("point(" + Ij + "," + Ik + ")");
+			throw new NotSquareMatrixException();
 		}
 	}
 	
@@ -350,17 +374,29 @@ public class LFTAnalysis{
 * @param baseMatrix ӸΥޥȥꥯ
 * @param compareMatrix Ӥޥȥꥯ
 * @return ˤޥȥꥯ
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
+* @exception DisagreementMatrixSizeException 2ĤΥޥȥꥯפʤ
 */
-	private Matrix getBlendMatrix(BooleanMatrix baseMatrix, BooleanMatrix compareMatrix){
-		Matrix returnMatrix = new Matrix(getElement(), getElement(),
-			baseMatrix.getRowNameArray(), baseMatrix.getColNameArray());
-		
-		for (int i = 0; i < getElement(); i++){
-			for (int j = 0; j < getElement(); j++){
-				returnMatrix.setCell(i, j, getBlendEdge(baseMatrix, compareMatrix, i ,j));
+	private ArithmeticMatrix getBlendMatrix(BooleanMatrix baseMatrix, BooleanMatrix compareMatrix){
+		if(baseMatrix.isSquare() && compareMatrix.isSquare()){
+			if (baseMatrix.isSameMatrixSize(compareMatrix)){
+				ArithmeticMatrix returnMatrix = new ArithmeticMatrix(getElement(), getElement(),
+					baseMatrix.getRowNameArray(), baseMatrix.getColNameArray());
+				
+				for (int i = 0; i < getElement(); i++){
+					for (int j = 0; j < getElement(); j++){
+						returnMatrix.setCell(i, j, getBlendEdge(baseMatrix, compareMatrix, i ,j));
+					}
+				}
+				return returnMatrix;
+			}
+			else{
+				throw new DisagreementMatrixSizeException();
 			}
 		}
-		return returnMatrix;
+		else{
+			throw new NotSquareMatrixException();
+		}
 	}
 	
 /**
@@ -371,19 +407,31 @@ public class LFTAnalysis{
 * @param baseMatrix ӸΥޥȥꥯ
 * @param compareMatrix Ӥޥȥꥯ
 * @return ˤޥȥꥯ
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
+* @exception DisagreementMatrixSizeException 2ĤΥޥȥꥯפʤ
 * @see #getBlend(BooleanMatrix baseMatrix, BooleanMatrix compareMatrix, int Ij, int Ik)
 * @see #getBlendStringMatrix()
 */
 	public StringMatrix getBlendStringMatrix(BooleanMatrix baseMatrix, BooleanMatrix compareMatrix){
-		StringMatrix returnMatrix = new StringMatrix(getElement(), getElement(),
-			baseMatrix.getRowNameArray(), baseMatrix.getColNameArray());
-		
-		for (int i = 0; i < getElement(); i++){
-			for (int j = 0; j < getElement(); j++){
-				returnMatrix.setCell(i, j, getBlend(baseMatrix, compareMatrix, i, j));
+		if(baseMatrix.isSquare() && compareMatrix.isSquare()){
+			if (baseMatrix.isSameMatrixSize(compareMatrix)){
+				StringMatrix returnMatrix = new StringMatrix(getElement(), getElement(),
+					baseMatrix.getRowNameArray(), baseMatrix.getColNameArray());
+				
+				for (int i = 0; i < getElement(); i++){
+					for (int j = 0; j < getElement(); j++){
+						returnMatrix.setCell(i, j, getBlend(baseMatrix, compareMatrix, i, j));
+					}
+				}
+				return returnMatrix;
+			}
+			else{
+				throw new DisagreementMatrixSizeException();
 			}
 		}
-		return returnMatrix;
+		else{
+			throw new NotSquareMatrixException();
+		}
 	}
 	
 /**
@@ -393,7 +441,7 @@ public class LFTAnalysis{
 * ˤޥȥꥯι̾̾϶ԤΥޥȥꥯƱˤʤޤ
 * @return ˤޥȥꥯ
 */
-	private Matrix getBlendMatrix(){
+	private ArithmeticMatrix getBlendMatrix(){
 		return getBlendMatrix(teacherMatrix, studentMatrix);
 	}
 	
@@ -416,27 +464,33 @@ public class LFTAnalysis{
 * @param Ij ͭޤλ
 * @param Ik ͭޤν
 * @return ɤǴ֤Фޥȥꥯ
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
 * @exception NotElementException ꤷֹ椬¸ߤʤ
 */
 	public BooleanMatrix getElementPairMatrix(BooleanMatrix nextMatrix, int Ij, int Ik){
-		if (nextMatrix.isMatrixEntityPoint(Ij, Ik)){
-			
-			//ãޥȥꥯ
-			BooleanMatrix lookMatrix = new BooleanMatrix(nextMatrix.getRowLength(), nextMatrix.getColLength(),
-				nextMatrix.getRowNameArray(), nextMatrix.getColNameArray());
-			lookMatrix.MatrixCopy(nextMatrix.getReachMatrix());
-			
-			BooleanMatrix returnMatrix = new BooleanMatrix(lookMatrix.getRowLength(), lookMatrix.getColLength(), 
-				lookMatrix.getRowNameArray(), lookMatrix.getColNameArray());
-			
-			//ޤ¸ߤ뤫ɤ
-			if (nextMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE){
-				returnMatrix.MatrixCopy(getPairMatrix(lookMatrix, Ij, Ik));
+		if(nextMatrix.isSquare()){
+			if (nextMatrix.isMatrixEntityPoint(Ij, Ik)){
+				
+				//ãޥȥꥯ
+				BooleanMatrix lookMatrix = new BooleanMatrix(nextMatrix.getRowLength(), nextMatrix.getColLength(),
+					nextMatrix.getRowNameArray(), nextMatrix.getColNameArray());
+				lookMatrix.matrixCopy(nextMatrix.getReachMatrix());
+				
+				BooleanMatrix returnMatrix = new BooleanMatrix(lookMatrix.getRowLength(), lookMatrix.getColLength(), 
+					lookMatrix.getRowNameArray(), lookMatrix.getColNameArray());
+				
+				//ޤ¸ߤ뤫ɤ
+				if (nextMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE){
+					returnMatrix.matrixCopy(getPairMatrix(lookMatrix, Ij, Ik));
+				}
+				return returnMatrix;
+			}
+			else{
+				throw new NotElementException("point(" + Ij + "," + Ik + ")");
 			}
-			return returnMatrix;
 		}
 		else{
-			throw new NotElementException("point(" + Ij + "," + Ik + ")");
+			throw new NotSquareMatrixException();
 		}
 	}
 	
@@ -446,32 +500,38 @@ public class LFTAnalysis{
 * @param Ij ͭޤλ
 * @param Ik ͭޤν
 * @return нȤʤޤν
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
 * @exception NotElementException ꤷֹ椬¸ߤʤ
 */
 	public EdgeSet getElementPairSet(BooleanMatrix nextMatrix, int Ij, int Ik){
-		if (nextMatrix.isMatrixEntityPoint(Ij, Ik)){
-			
-			//ãޥȥꥯ
-			BooleanMatrix lookMatrix = new BooleanMatrix(nextMatrix.getRowLength(), nextMatrix.getColLength(),
-				nextMatrix.getRowNameArray(), nextMatrix.getColNameArray());
-			lookMatrix.MatrixCopy(nextMatrix.getReachMatrix());
-			
-			EdgeSet edgeHash = new EdgeSet();
-			
-			//ޤ¸ߤ뤫ɤ
-			if (nextMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE){
-				for (int i = 0; i < lookMatrix.getRowLength(); i++){
-					for (int j = 0; j < lookMatrix.getColLength(); j++){
-						if (lookMatrix.getCell(i, Ij) && lookMatrix.getCell(Ik, j) == LFT_EDGE_TRUE){
-							edgeHash.add(new Edge(i,j));
+		if(nextMatrix.isSquare()){
+			if (nextMatrix.isMatrixEntityPoint(Ij, Ik)){
+				
+				//ãޥȥꥯ
+				BooleanMatrix lookMatrix = new BooleanMatrix(nextMatrix.getRowLength(), nextMatrix.getColLength(),
+					nextMatrix.getRowNameArray(), nextMatrix.getColNameArray());
+				lookMatrix.matrixCopy(nextMatrix.getReachMatrix());
+				
+				EdgeSet edgeHash = new EdgeSet();
+				
+				//ޤ¸ߤ뤫ɤ
+				if (nextMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE){
+					for (int i = 0; i < lookMatrix.getRowLength(); i++){
+						for (int j = 0; j < lookMatrix.getColLength(); j++){
+							if (lookMatrix.getCell(i, Ij) && lookMatrix.getCell(Ik, j) == LFT_EDGE_TRUE){
+								edgeHash.add(new Edge(i,j));
+							}
 						}
 					}
 				}
+				return edgeHash;
+			}
+			else{
+				throw new NotElementException("point(" + Ij + "," + Ik + ")");
 			}
-			return edgeHash;
 		}
 		else{
-			throw new NotElementException("point(" + Ij + "," + Ik + ")");
+			throw new NotSquareMatrixException();
 		}
 	}
 	
@@ -483,26 +543,32 @@ public class LFTAnalysis{
 * @param Ij ͭޤθֹ
 * @param Ik ͭޤֹ
 * @return ɤǴ֤Фޥȥꥯ
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
 * @exception NotElementException ꤷֹ椬¸ߤʤ
 */
 	private BooleanMatrix getPairMatrix(BooleanMatrix lookMatrix, int Ij, int Ik){
-		if (lookMatrix.isMatrixEntityPoint(Ij, Ik)){
-			BooleanMatrix returnMatrix = new BooleanMatrix(lookMatrix.getRowLength(),lookMatrix.getColLength(), 
-				lookMatrix.getRowNameArray(), lookMatrix.getColNameArray());
-			for (int i = 0; i < lookMatrix.getRowLength(); i++){
-				for (int j = 0; j < lookMatrix.getColLength(); j++){
-					if (lookMatrix.getCell(i, Ij) && lookMatrix.getCell(Ik, j) == LFT_EDGE_TRUE){
-						returnMatrix.setCell(i, j, LFT_EDGE_TRUE);
-					}
-					else{
-						returnMatrix.setCell(i, j, LFT_EDGE_FALSE);
+		if(lookMatrix.isSquare()){
+			if (lookMatrix.isMatrixEntityPoint(Ij, Ik)){
+				BooleanMatrix returnMatrix = new BooleanMatrix(lookMatrix.getRowLength(),lookMatrix.getColLength(), 
+					lookMatrix.getRowNameArray(), lookMatrix.getColNameArray());
+				for (int i = 0; i < lookMatrix.getRowLength(); i++){
+					for (int j = 0; j < lookMatrix.getColLength(); j++){
+						if (lookMatrix.getCell(i, Ij) && lookMatrix.getCell(Ik, j) == LFT_EDGE_TRUE){
+							returnMatrix.setCell(i, j, LFT_EDGE_TRUE);
+						}
+						else{
+							returnMatrix.setCell(i, j, LFT_EDGE_FALSE);
+						}
 					}
 				}
+				return returnMatrix;
+			}
+			else{
+				throw new NotElementException("point(" + Ij + "," + Ik + ")");
 			}
-			return returnMatrix;
 		}
 		else{
-			throw new NotElementException("point(" + Ij + "," + Ik + ")");
+			throw new NotSquareMatrixException();
 		}
 	}
 	
@@ -510,17 +576,23 @@ public class LFTAnalysis{
 * ޥȥꥯ¸ߤޤν٤ޤ
 * @param baseMatrix ٤оݤܥޥȥꥯ
 * @return ޤν٤Ǽޥȥꥯ
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
 */
-	public Matrix getImportantEdgeMatrix(BooleanMatrix baseMatrix){
-		Matrix returnMatrix = new Matrix(baseMatrix.getRowLength(), baseMatrix.getColLength(),
-			baseMatrix.getRowNameArray(), baseMatrix.getColNameArray());
-		
-		for (int i = 0;i < baseMatrix.getRowLength(); i++){
-			for (int j = 0; j < baseMatrix.getColLength(); j++){
-				returnMatrix.setCell(i, j, getImportantEdge(baseMatrix, i, j));
+	public ArithmeticMatrix getImportantEdgeMatrix(BooleanMatrix baseMatrix){
+		if(baseMatrix.isSquare()){
+			ArithmeticMatrix returnMatrix = new ArithmeticMatrix(baseMatrix.getRowLength(), baseMatrix.getColLength(),
+				baseMatrix.getRowNameArray(), baseMatrix.getColNameArray());
+			
+			for (int i = 0;i < baseMatrix.getRowLength(); i++){
+				for (int j = 0; j < baseMatrix.getColLength(); j++){
+					returnMatrix.setCell(i, j, getImportantEdge(baseMatrix, i, j));
+				}
 			}
+			return returnMatrix;
+		}
+		else{
+			throw new NotSquareMatrixException();
 		}
-		return returnMatrix;
 	}
 	
 /**
@@ -529,19 +601,25 @@ public class LFTAnalysis{
 * @param Ij ͭޤλȤʤIj
 * @param Ik ͭޤνȤʤIk
 * @return ꤷܴ֤ν
+* @exception NotSquareMatrixException ꤷޥȥꥯǤϤʤ
 */
 	public double getImportantEdge(BooleanMatrix baseMatrix, int Ij, int Ik){
-		BooleanMatrix temporaryMatrix = new BooleanMatrix(baseMatrix.getRowLength(), baseMatrix.getColLength());
-		double cont = Math.floor(getElement() / 2) * Math.floor((getElement() + 1) / 2);
-		double value = 0.0;
+		if(baseMatrix.isSquare()){
+			BooleanMatrix temporaryMatrix = new BooleanMatrix(baseMatrix.getRowLength(), baseMatrix.getColLength());
+			double cont = Math.floor(getElement() / 2) * Math.floor((getElement() + 1) / 2);
+			double value = 0.0;
 			
-		//ޤ¸ߤ뤫ɤ
-		if (baseMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE){
-			temporaryMatrix.MatrixCopy(getElementPairMatrix(baseMatrix, Ij, Ik));
-			value = temporaryMatrix.getElement();
-			value = value / cont;
+			//ޤ¸ߤ뤫ɤ
+			if (baseMatrix.getCell(Ij, Ik) == LFT_EDGE_TRUE){
+				temporaryMatrix.matrixCopy(getElementPairMatrix(baseMatrix, Ij, Ik));
+				value = temporaryMatrix.getElement();
+				value = value / cont;
+			}
+			return value;
+		}
+		else{
+			throw new NotSquareMatrixException();
 		}
-		return value;
 	}
 	
 /**
@@ -568,7 +646,7 @@ public class LFTAnalysis{
 * @see #getEdgeStudentMatrix()
 * @see #getImportantEdgeTeacher(int Ij, int Ik)
 */
-	public Matrix getEdgeTeacherMatrix(){
+	public ArithmeticMatrix getEdgeTeacherMatrix(){
 		return getImportantEdgeMatrix(teacherMatrix);
 	}
 	
@@ -596,7 +674,7 @@ public class LFTAnalysis{
 * @see #getEdgeStudentMatrix()
 * @see #getImportantEdgeTeacher(int Ij, int Ik)
 */
-	public Matrix getEdgeStudentMatrix(){
+	public ArithmeticMatrix getEdgeStudentMatrix(){
 		return getImportantEdgeMatrix(studentMatrix);
 	}
 	
@@ -625,8 +703,7 @@ public class LFTAnalysis{
 */
 	public BooleanMatrix getReachTeacherMatrix(){
 		BooleanMatrix reachTeacherMatrix = new BooleanMatrix();
-		reachTeacherMatrix.MatrixCopy(teacherMatrix.getReachMatrix());
-		//reachTeacherMatrix.convertLogicMatrix();
+		reachTeacherMatrix.matrixCopy(teacherMatrix.getReachMatrix());
 		return reachTeacherMatrix;
 	}
 	
@@ -637,7 +714,7 @@ public class LFTAnalysis{
 */
 	public BooleanMatrix getReachStudentMatrix(){
 		BooleanMatrix reachStudentMatrix = new BooleanMatrix();
-		reachStudentMatrix.MatrixCopy(studentMatrix.getReachMatrix());
+		reachStudentMatrix.matrixCopy(studentMatrix.getReachMatrix());
 		return reachStudentMatrix;
 	}
 	
@@ -683,8 +760,8 @@ public class LFTAnalysis{
 * @see #getStudentOnlyEdge()
 */
 	public int getTotelEdge(){
-		Matrix mixMatrix = new Matrix(getElement(), getElement());
-		mixMatrix.MatrixCopy(getBlendMatrix());
+		ArithmeticMatrix mixMatrix = new ArithmeticMatrix(getElement(), getElement());
+		mixMatrix.matrixCopy(getBlendMatrix());
 		return mixMatrix.getElement();
 	}
 	
@@ -698,8 +775,8 @@ public class LFTAnalysis{
 */
 	public int getTeacherOnlyEdge(){
 		int count = 0;
-		Matrix mixMatrix = new Matrix(getElement(), getElement());
-		mixMatrix.MatrixCopy(getBlendMatrix());
+		ArithmeticMatrix mixMatrix = new ArithmeticMatrix(getElement(), getElement());
+		mixMatrix.matrixCopy(getBlendMatrix());
 		for (int i = 0; i < mixMatrix.getRowLength(); i++){
 			for (int j = 0; j < mixMatrix.getColLength(); j++){
 				if (mixMatrix.getCell(i, j) == LFT_EDGE_TEACHER){
@@ -720,8 +797,8 @@ public class LFTAnalysis{
 */
 	public int getStudentOnlyEdge(){
 		int count = 0;
-		Matrix mixMatrix = new Matrix(getElement(), getElement());
-		mixMatrix.MatrixCopy(getBlendMatrix());
+		ArithmeticMatrix mixMatrix = new ArithmeticMatrix(getElement(), getElement());
+		mixMatrix.matrixCopy(getBlendMatrix());
 		for (int i = 0; i < mixMatrix.getRowLength(); i++){
 			for (int j = 0; j < mixMatrix.getColLength(); j++){
 				if (mixMatrix.getCell(i, j) == LFT_EDGE_STUDENT){
@@ -743,8 +820,8 @@ public class LFTAnalysis{
 */
 	public int getAccordEdge(){
 		int count = 0;
-		Matrix mixMatrix = new Matrix(getElement(), getElement());
-		mixMatrix.MatrixCopy(getBlendMatrix());
+		ArithmeticMatrix mixMatrix = new ArithmeticMatrix(getElement(), getElement());
+		mixMatrix.matrixCopy(getBlendMatrix());
 		for (int i = 0; i < mixMatrix.getRowLength(); i++){
 			for (int j = 0; j < mixMatrix.getColLength(); j++){
 				if (mixMatrix.getCell(i, j) == LFT_EDGE_INT_TRUE){
@@ -763,7 +840,7 @@ public class LFTAnalysis{
 	private void setTeacherMatrix(BooleanMatrix baseTeacherMatrix){
 		if (baseTeacherMatrix.isSquare()){
 			teacherMatrix = new BooleanMatrix();
-			teacherMatrix.MatrixCopy(baseTeacherMatrix);
+			teacherMatrix.matrixCopy(baseTeacherMatrix);
 		}
 		else{
 			throw new NotSquareMatrixException();
@@ -781,7 +858,7 @@ public class LFTAnalysis{
 		if (baseStudentMatrix.isSquare()){
 			if (teacherMatrix.isSameMatrixSize(baseStudentMatrix)){
 				studentMatrix = new BooleanMatrix();
-				studentMatrix.MatrixCopy(baseStudentMatrix);
+				studentMatrix.matrixCopy(baseStudentMatrix);
 			}
 			else{
 				throw new DisagreementMatrixSizeException();
