@@ -3,18 +3,18 @@ package jp.ac.takushoku_u.cs;
 /**
 * SSAnalysis饹SSʬϤ׻뤿Υ饹Ǥ<BR>
 * 1nޤǤnʳΥ󥱡ȥǡʬϤ뤳ȤǤޤ
-* @version 1.12
+* @version 1.2
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ1022
+* ǽ 2004ǯ1124
 */
 public class SSAnalysis{
 
 /**
 * ʬϸΥޥȥꥯݻޥȥꥯ
 */
-	private Matrix matrix;
+	private ArithmeticMatrix matrix;
 
 /**
 * 󥱡Ȥηݻѿ
@@ -82,7 +82,7 @@ public class SSAnalysis{
 * ɾκͤϥޥȥꥯκͤˡͤϥǥեͤȤʤޤ
 */
 	public SSAnalysis(){
-		Matrix baseMatrix = new Matrix(SSANALYSIS_MATRIX_VALUE,SSANALYSIS_MATRIX_VALUE);		//ޥȥꥯκ
+		ArithmeticMatrix baseMatrix = new ArithmeticMatrix(SSANALYSIS_MATRIX_VALUE,SSANALYSIS_MATRIX_VALUE);		//ޥȥꥯκ
 		setMatrix(baseMatrix);		//ޥȥꥯ
 		setScale(SSANALYSIS_SCALE_TYPE);		//󥱡Ȥη
 		matrix.clearMatrix();		//ޥȥꥯǤ
@@ -95,7 +95,7 @@ public class SSAnalysis{
 * 󥱡ȤηIɾκͤϥޥȥꥯκͤˡͤϥǥեȤȤʤޤ
 * @param baseMatrix ʬϤԤޥȥꥯ
 */
-	public SSAnalysis(Matrix baseMatrix){
+	public SSAnalysis(ArithmeticMatrix baseMatrix){
 		setMatrix(baseMatrix);
 		setScale(SSANALYSIS_SCALE_TYPE);
 		setRating((int) matrix.getMaxCell());
@@ -109,7 +109,7 @@ public class SSAnalysis{
 * @param scale 󥱡Ȥη
 * @exception SetValueOutOfBoundsException 󥱡ȤηǤ
 */
-	public SSAnalysis(Matrix baseMatrix, int scale){
+	public SSAnalysis(ArithmeticMatrix baseMatrix, int scale){
 		setMatrix(baseMatrix);
 		setScale(scale);
 		setRating((int) matrix.getMaxCell());
@@ -124,7 +124,7 @@ public class SSAnalysis{
 * @param threshold 
 * @exception SetValueOutOfBoundsException 󥱡ȤηǤ硢ͤǤϰϳξ
 */
-	public SSAnalysis(Matrix baseMatrix, int scale, double threshold){
+	public SSAnalysis(ArithmeticMatrix baseMatrix, int scale, double threshold){
 		setMatrix(baseMatrix);
 		setScale(scale);
 		setRating((int) matrix.getMaxCell());
@@ -140,7 +140,7 @@ public class SSAnalysis{
 * @param rating ɾκ
 * @exception SetValueOutOfBoundsException 󥱡ȤηǤ硢ޤϤͤǤϰϳξ
 */
-	public SSAnalysis(Matrix baseMatrix, int scale, double threshold, int rating){
+	public SSAnalysis(ArithmeticMatrix baseMatrix, int scale, double threshold, int rating){
 		setMatrix(baseMatrix);
 		setScale(scale);
 		setRating(rating);
@@ -154,15 +154,15 @@ public class SSAnalysis{
 * @see #getCoefficientMatrix()
 * @see #getSkeletonMatrix()
 */
-	public Matrix getSSMatrix(){
+	public ArithmeticMatrix getSSMatrix(){
 		
 		//֤SSޥȥꥯ
-		Matrix returnMatrix = new Matrix(matrix.getColLength(), matrix.getColLength(), 
+		ArithmeticMatrix returnMatrix = new ArithmeticMatrix(matrix.getColLength(), matrix.getColLength(), 
 			matrix.getColNameArray(), matrix.getColNameArray());
 		
 		//ޡ˷ɽ
-		Matrix coefficientMatrix = new Matrix(matrix.getColLength(), matrix.getColLength());
-		coefficientMatrix.MatrixCopy(getCoefficientMatrix());
+		ArithmeticMatrix coefficientMatrix = new ArithmeticMatrix(matrix.getColLength(), matrix.getColLength());
+		coefficientMatrix.matrixCopy(getCoefficientMatrix());
 		
 		int value;
 		for (int i = 0; i <  matrix.getColLength(); i++){
@@ -185,10 +185,10 @@ public class SSAnalysis{
 * @see #getSSMatrix()
 * @see #getSkeletonMatrix()
 */
-	public Matrix getCoefficientMatrix(){
+	public ArithmeticMatrix getCoefficientMatrix(){
 		
 		//֤ޡɽ
-		 Matrix returnMatrix = new Matrix(matrix.getColLength(), matrix.getColLength(),
+		 ArithmeticMatrix returnMatrix = new ArithmeticMatrix(matrix.getColLength(), matrix.getColLength(),
 		 	matrix.getColNameArray(), matrix.getColNameArray());
 		
 		for (int i = 0; i < matrix.getColLength(); i++){
@@ -236,11 +236,11 @@ public class SSAnalysis{
 * @return IjIkؤٿʬɽ
 * @exception NotElementException ꤷֹ椬¸ߤʤ
 */
-	public Matrix getFrequencyMatrix(int Ij, int Ik){
+	public ArithmeticMatrix getFrequencyMatrix(int Ij, int Ik){
 		if (matrix.isMatrixEntityPoint(Ij, Ik)){
 			
 			//֤ٿʬɽ
-			Matrix returnTable = new Matrix(getMaxValue(), getMaxValue());
+			ArithmeticMatrix returnTable = new ArithmeticMatrix(getMaxValue(), getMaxValue());
 			returnTable.clearMatrix();
 			for (int i = 0; i < matrix.getRowLength(); i++){		//ٿʬɽκ
 				double value = returnTable.getCell((int) matrix.getCell(i, Ij) -1,
@@ -264,7 +264,7 @@ public class SSAnalysis{
 */
 	private double getAscendingCoefficient(int Ij, int Ik){
 		double value = 0;
-		Matrix frequencyMatrix = new Matrix(getMaxValue(), getMaxValue());
+		ArithmeticMatrix frequencyMatrix = new ArithmeticMatrix(getMaxValue(), getMaxValue());
 		frequencyMatrix = getFrequencyMatrix(Ij, Ik);	//ٿʬɽ
 
 		for (int i = 1; i <= ( frequencyMatrix.getRowLength() - 1); i++){	//
@@ -288,7 +288,7 @@ public class SSAnalysis{
 		double numeratorU = (matrix.getRowLength() *
 			(getMaxValue() - 1) * (getMaxValue() - 1)) / 4;	//ʬ
 		double gravity;		//Ť((r-m0)^2-(q-m0)^2)
-		Matrix frequencyMatrix = new Matrix(getMaxValue(), getMaxValue());
+		ArithmeticMatrix frequencyMatrix = new ArithmeticMatrix(getMaxValue(), getMaxValue());
 		frequencyMatrix = getFrequencyMatrix(Ij, Ik);		//ٿʬɽ
 
 		for (int i = 1; i <= getMaxValue(); i++){		//
@@ -316,8 +316,8 @@ public class SSAnalysis{
 		//ʬκd0
 		double numeratorD = ((matrix.getRowLength() * matrix.getRowLength()) *
 			(getMaxValue() - 1)) / (2 * getMaxValue());
-		Matrix frequencyMatrix = new Matrix(getMaxValue(), getMaxValue());
-		frequencyMatrix.MatrixCopy(getFrequencyMatrix(Ij, Ik));	//ٿʬɽ
+		ArithmeticMatrix frequencyMatrix = new ArithmeticMatrix(getMaxValue(), getMaxValue());
+		frequencyMatrix.matrixCopy(getFrequencyMatrix(Ij, Ik));	//ٿʬɽ
 
 		for (int i = 1; i <= getMaxValue(); i++){		//
 			for (int j = 1; j <= getMaxValue(); j++){
@@ -340,8 +340,8 @@ public class SSAnalysis{
 * @see #getSSMatrix()
 * @see #getCoefficientMatrix()
 */
-	public Matrix getSkeletonMatrix(){
-		Matrix SkeletonMatrix = new Matrix(matrix.getColLength(), matrix.getColLength(),
+	public ArithmeticMatrix getSkeletonMatrix(){
+		ArithmeticMatrix SkeletonMatrix = new ArithmeticMatrix(matrix.getColLength(), matrix.getColLength(),
 			matrix.getColNameArray(), matrix.getColNameArray());
 		
 		int[] highOrder = new int[matrix.getColLength()];
@@ -349,8 +349,8 @@ public class SSAnalysis{
 		SkeletonMatrix.clearMatrix();
 		
 		//SSޥȥꥯ
-		Matrix ssMatrix = new Matrix(matrix.getColLength(), matrix.getColLength());
-		ssMatrix.MatrixCopy(getSSMatrix());
+		ArithmeticMatrix ssMatrix = new ArithmeticMatrix(matrix.getColLength(), matrix.getColLength());
+		ssMatrix.matrixCopy(getSSMatrix());
 		
 		for (int i = 0; i < SkeletonMatrix.getRowLength(); i++){
 			int searchRow = highOrder[i];	 //ºݤ˸Ԥԡʿɾͤι⤤ǡ
@@ -494,8 +494,8 @@ public class SSAnalysis{
 * IIʬϤκݤѤޤ
 * @return ΥޥȥꥯǤͤͤäޥȥꥯ
 */
-	private Matrix getMiddleMomentMatrix(){
-		Matrix returnMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(), matrix.getRowNameArray(),
+	private ArithmeticMatrix getMiddleMomentMatrix(){
+		ArithmeticMatrix returnMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(), matrix.getRowNameArray(),
 			matrix.getColNameArray());
 		double centerRating = (getMaxValue() + 1) / 2;		//ɾ
 		for (int i = 0; i < matrix.getRowLength(); i++){
@@ -512,9 +512,9 @@ public class SSAnalysis{
 * @return ͤͤä
 */
 	private double[] getMiddleAverageArray(){
-		Matrix calculationMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(), matrix.getRowNameArray(),
+		ArithmeticMatrix calculationMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(), matrix.getRowNameArray(),
 			matrix.getColNameArray());
-		calculationMatrix.MatrixCopy(getMiddleMomentMatrix());
+		calculationMatrix.matrixCopy(getMiddleMomentMatrix());
 		return calculationMatrix.getColAverageArray();
 	}
 
@@ -549,11 +549,11 @@ public class SSAnalysis{
 */
 	private double[] getNonSortCategoryArray(){
 		double[] returnArray = new double[matrix.getColLength()];
-		Matrix frequencyTable = new Matrix(getMaxValue(), getMaxValue());
+		ArithmeticMatrix frequencyTable = new ArithmeticMatrix(getMaxValue(), getMaxValue());
 
 		for (int i = 0; i < matrix.getColLength(); i++){		//ͭƥ꡼
 			double value = 0;
-			frequencyTable.MatrixCopy(getFrequencyMatrix(i,i));
+			frequencyTable.matrixCopy(getFrequencyMatrix(i,i));
 			for (int j = 0; j < getMaxValue(); j++){
 				value = (frequencyTable.getCell(j,j) / matrix.getRowLength())
 				* (frequencyTable.getCell(j,j) / matrix.getRowLength()) + value;
@@ -592,7 +592,7 @@ public class SSAnalysis{
 * ʬϤԤΥޥȥꥯ֤ޤ
 * @return ʬϤԤθΥޥȥꥯ
 */
-	public Matrix getMatrix(){
+	public ArithmeticMatrix getMatrix(){
 		return matrix;
 	}
 
@@ -625,9 +625,9 @@ public class SSAnalysis{
 * @param baseMatrix ꤹʬоݤΥޥȥꥯ
 * @see #setElement(int row, int col, int value)
 */
-	public void setMatrix(Matrix baseMatrix){
-		matrix = new Matrix(baseMatrix.getRowLength(), baseMatrix.getColLength());
-		matrix.MatrixCopy(baseMatrix);		//ޥȥꥯ
+	public void setMatrix(ArithmeticMatrix baseMatrix){
+		matrix = new ArithmeticMatrix(baseMatrix.getRowLength(), baseMatrix.getColLength());
+		matrix.matrixCopy(baseMatrix);		//ޥȥꥯ
 	}
 
 /**
@@ -636,7 +636,7 @@ public class SSAnalysis{
 * @param col Ǥ
 * @param value 
 * @exception NotElementException ꤷǤ¸ߤʤ
-* @see #setMatrix(Matrix baseMatrix)
+* @see #setMatrix(ArithmeticMatrix baseMatrix)
 */
 	public void setElement(int row, int col, int value){
 		if (matrix.isMatrixEntityPoint(row, col)){
