@@ -3,14 +3,14 @@ package jp.ac.takushoku_u.cs;
 /**
 * SetValueOutOfBoundsException饹ͤԤݤˡ
 * ԤȤǤϰϳꤷ褦ȤȤ򼨤˥ޤ
-* @version 1.1
+* @version 1.2
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ0927
+* ǽ 2004ǯ1209
 */
 
-public class SetValueOutOfBoundsException extends OutOfBoundsException{
+public class SetValueOutOfBoundsException extends IllegalValueException{
 
 /**
 * åʤ SetValueOutOfBoundsException ۤޤ
