@@ -5,22 +5,22 @@ package jp.ac.takushoku_u.cs;
 * 󲽤Ԥ˲۹ܤɬפǤ깽¤ξǤäƤ⡢
 * ưŪ˲۹ܤͿ󲽤ԤȤǤޤ
 * ۹ܤ0ܤ0ܤͿ졢̾̾Ϥ`Dummy'Ȥʤޤ
-* @version 1.0
+* @version 1.1.1
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ1116
+* ǽ 2004ǯ1206
 */
 public class TaskSequence{
 	
 /**
 * 󲽤Ԥܥޥȥꥯ(۹ܤʤ)
 */
-	private Matrix baseMatrix;
+	private ArithmeticMatrix baseMatrix;
 /**
 * 󲽤Ԥܥޥȥꥯ(۹)
 */	
-	private Matrix matrix;
+	private ArithmeticMatrix matrix;
 	
 /**
 * ۹ܤͿѿ
@@ -56,8 +56,8 @@ public class TaskSequence{
 * ǥեȤꤵƤͤǷ󲽤Ԥܥޥȥꥯꤷޤ
 */
 	public TaskSequence(){
-		baseMatrix = new Matrix(TASK_SEQUENCE_MATRIX_SIZE, TASK_SEQUENCE_MATRIX_SIZE);
-		matrix = new Matrix(TASK_SEQUENCE_MATRIX_SIZE, TASK_SEQUENCE_MATRIX_SIZE);
+		baseMatrix = new ArithmeticMatrix(TASK_SEQUENCE_MATRIX_SIZE, TASK_SEQUENCE_MATRIX_SIZE);
+		matrix = new ArithmeticMatrix(TASK_SEQUENCE_MATRIX_SIZE, TASK_SEQUENCE_MATRIX_SIZE);
 	}
 	
 /**
@@ -65,9 +65,9 @@ public class TaskSequence{
 * @param adjacencyMatrix ܥޥȥꥯ
 * @exception NotSquareMatrixException ܥޥȥꥯǤϤʤ
 */
-	public TaskSequence(Matrix adjacencyMatrix){
-		baseMatrix = new Matrix(adjacencyMatrix.getRowLength(), adjacencyMatrix.getColLength());
-		matrix = new Matrix(adjacencyMatrix.getRowLength(), adjacencyMatrix.getColLength());
+	public TaskSequence(ArithmeticMatrix adjacencyMatrix){
+		baseMatrix = new ArithmeticMatrix(adjacencyMatrix.getRowLength(), adjacencyMatrix.getColLength());
+		matrix = new ArithmeticMatrix(adjacencyMatrix.getRowLength(), adjacencyMatrix.getColLength());
 		setMatrix(adjacencyMatrix);
 	}
 	
@@ -77,7 +77,7 @@ public class TaskSequence{
 * @return ܥޥȥꥯ
 * @see #getDummyMatrix()
 */
-	public Matrix getMatrix(){
+	public ArithmeticMatrix getMatrix(){
 		return baseMatrix;
 	}
 	
@@ -87,119 +87,154 @@ public class TaskSequence{
 * @return ۹ܤͿܥޥȥꥯ
 * @see #getMatrix()
 */
-	public Matrix getDummyMatrix(){
+	public ArithmeticMatrix getDummyMatrix(){
 		return matrix;
 	}
 	
 /**
-* ãޥȥꥯޤ
+* ãޥȥꥯ֤ޤ
 * ۹ܤɬפܥޥȥꥯꤷ硢۹ܹߤΥޥȥꥯ֤ޤ
 * @return ãޥȥꥯ
 */
-	public Matrix getReachMatrix(){
+	public ArithmeticMatrix getReachMatrix(){
 		return getReachMatrix(matrix);
 	}
 	
 /**
-* ܥޥȥꥯãޥȥꥯޤ
+* ܥޥȥꥯãޥȥꥯ֤ޤ
 * @param adjacencyMatrix ܥޥȥꥯ
 * @return ãޥȥꥯ
 */
-	private Matrix getReachMatrix(Matrix adjacencyMatrix){
-		Matrix returnMatrix = new Matrix(adjacencyMatrix.getRowLength(),
+	private ArithmeticMatrix getReachMatrix(ArithmeticMatrix adjacencyMatrix){
+		ArithmeticMatrix returnMatrix = new ArithmeticMatrix(adjacencyMatrix.getRowLength(),
 			adjacencyMatrix.getColLength(), adjacencyMatrix.getRowNameArray(), adjacencyMatrix.getColNameArray());
 		return adjacencyMatrix.getReachMatrix();
 	}
 	
 /**
-* ޥȥꥯޤ
+* ޥȥꥯ֤ޤ
 * ۹ܤɬפܥޥȥꥯꤷ硢۹ܹߤΥޥȥꥯ֤ޤ
 * @return ޥȥꥯ
 */
-	public Matrix getFMatrix(){
-		Matrix reachMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+	public ArithmeticMatrix getFMatrix(){
+		ArithmeticMatrix reachMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 			matrix.getRowNameArray(), matrix.getColNameArray());
-		reachMatrix.MatrixCopy(getReachMatrix(matrix));
+		reachMatrix.matrixCopy(getReachMatrix(matrix));
 		
 		return getFMatrix(reachMatrix);
 	}
 	
 /**
-* ãޥȥꥯޥȥꥯޤ
-* @param ãޥȥꥯ
+* ãޥȥꥯޥȥꥯ֤ޤ
+* @param reachMatrix ãޥȥꥯ
 * @return ޥȥꥯ
 */
-	private Matrix getFMatrix(Matrix reachMatrix){
-		Matrix returnMatrix = new Matrix(reachMatrix.getRowLength(), reachMatrix.getColLength(),
+	private ArithmeticMatrix getFMatrix(ArithmeticMatrix reachMatrix){
+		ArithmeticMatrix returnMatrix = new ArithmeticMatrix(reachMatrix.getRowLength(), reachMatrix.getColLength(),
 			reachMatrix.getRowNameArray(), reachMatrix.getColNameArray());
-		Matrix TMatrix = new Matrix(reachMatrix.getRowLength(), reachMatrix.getColLength(),
+		ArithmeticMatrix TMatrix = new ArithmeticMatrix(reachMatrix.getRowLength(), reachMatrix.getColLength(),
 			reachMatrix.getRowNameArray(), reachMatrix.getColNameArray());
 		
-		TMatrix.MatrixCopy(reachMatrix.getTransposedMatrix());
-		returnMatrix.MatrixCopy(TMatrix.getMultiplyMatrix(reachMatrix));
+		TMatrix.matrixCopy(reachMatrix.getTransposedMatrix());
+		returnMatrix.matrixCopy(TMatrix.getMultiplyMatrix(reachMatrix));
 		return returnMatrix;
 	}
 	
 /**
-* ɸޥȥꥯޤ
+* ɸޥȥꥯ֤ޤ
 * ۹ܤɬפܥޥȥꥯꤷ硢۹ܹߤΥޥȥꥯ֤ޤ
 * @return ɸޥȥꥯ
 */
-	public Matrix getGMatrix(){
-		Matrix reachMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+	public ArithmeticMatrix getGMatrix(){
+		ArithmeticMatrix reachMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 			matrix.getRowNameArray(), matrix.getColNameArray());
-		reachMatrix.MatrixCopy(getReachMatrix(matrix));
+		reachMatrix.matrixCopy(getReachMatrix(matrix));
 		
 		return getGMatrix(reachMatrix);
 	}
 	
 /**
-* ãޥȥꥯɸޥȥꥯޤ
-* @param ãޥȥꥯ
+* ãޥȥꥯɸޥȥꥯ֤ޤ
+* @param reachMatrix ãޥȥꥯ
 * @return ɸޥȥꥯ
 */
-	private Matrix getGMatrix(Matrix reachMatrix){
-		Matrix returnMatrix = new Matrix(reachMatrix.getRowLength(), reachMatrix.getColLength(),
+	private ArithmeticMatrix getGMatrix(ArithmeticMatrix reachMatrix){
+		ArithmeticMatrix returnMatrix = new ArithmeticMatrix(reachMatrix.getRowLength(), reachMatrix.getColLength(),
 			reachMatrix.getRowNameArray(), reachMatrix.getColNameArray());
-		Matrix TMatrix = new Matrix(reachMatrix.getRowLength(), reachMatrix.getColLength(),
+		ArithmeticMatrix TMatrix = new ArithmeticMatrix(reachMatrix.getRowLength(), reachMatrix.getColLength(),
 			reachMatrix.getRowNameArray(), reachMatrix.getColNameArray());
 		
-		TMatrix.MatrixCopy(reachMatrix.getTransposedMatrix());
-		returnMatrix.MatrixCopy(reachMatrix.getMultiplyMatrix(TMatrix));
+		TMatrix.matrixCopy(reachMatrix.getTransposedMatrix());
+		returnMatrix.matrixCopy(reachMatrix.getMultiplyMatrix(TMatrix));
 		return returnMatrix;
 	}
 	
 /**
-* ҡޥȥꥯޤ
+* 2ܴ֤ι֤ޤ
+* ۹ܤɬפܥޥȥꥯꤷ硢۹ܤθ֤ͤޤ
+* ۹ܤꤹɬפΤܥޥȥꥯξ硢
+* ܥޥȥꥯιֹvivjֹ椬פʤդɬפǤ
+* @param vi vi
+* @param vj vj
+* @return 
+* @exception NotElementException ꤵ줿¸ߤʤ
+*/
+
+	public double getF(int vi, int vj){
+		
+		ArithmeticMatrix mat = new ArithmeticMatrix();
+		mat.matrixCopy(getFMatrix());
+		return mat.getCell(vi, vj);		//¸ߤʤ㳰
+	}
+	
+/**
+* 2ܴ֤ιɸ֤ޤ
+* ۹ܤɬפܥޥȥꥯꤷ硢۹ܤθ֤ͤޤ
+* ۹ܤꤹɬפΤܥޥȥꥯξ硢
+* ܥޥȥꥯιֹvivjֹ椬פʤդɬפǤ
+* @param vi vi
+* @param vj vj
+* @return ɸ
+* @exception NotElementException ꤵ줿¸ߤʤ
+*/
+	public double getG(int vi, int vj){
+		
+		ArithmeticMatrix mat = new ArithmeticMatrix();
+		mat.matrixCopy(getGMatrix());
+		return mat.getCell(vi, vj);		//¸ߤʤ㳰
+	}
+	
+/**
+* ҡޥȥꥯ֤ޤ
 * ֤륳ҡޥȥꥯϡޥȥꥯ + ɸޥȥꥯǤ
 * ۹ܤɬפܥޥȥꥯꤷ硢۹ܹߤΥޥȥꥯ֤ޤ
 * @return ҡޥȥꥯ
 */
-	public Matrix getCoherenceMatrix(){
-		Matrix FMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+	public ArithmeticMatrix getCoherenceMatrix(){
+		ArithmeticMatrix FMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 			matrix.getRowNameArray(), matrix.getColNameArray());
-		Matrix GMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+		ArithmeticMatrix GMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 			matrix.getRowNameArray(), matrix.getColNameArray());
-		FMatrix.MatrixCopy(getFMatrix());
-		GMatrix.MatrixCopy(getGMatrix());
+		FMatrix.matrixCopy(getFMatrix());
+		GMatrix.matrixCopy(getGMatrix());
 		return getCoherenceMatrix(FMatrix, GMatrix);
 	}
 	
 /**
-* ҡޥȥꥯޤ
+* ҡޥȥꥯ֤ޤ
 * ֤륳ҡޥȥꥯϡޥȥꥯ + ɸޥȥꥯǤ
 * ۹ܤɬפܥޥȥꥯꤷ硢۹ܹߤΥޥȥꥯ֤ޤ
 * @param alpha ե
 * @param beta ١
 * @return ҡޥȥꥯ
 */
-	public Matrix getCoherenceMatrix(double alpha, double beta){
-		Matrix FMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+	public ArithmeticMatrix getCoherenceMatrix(double alpha, double beta){
+		ArithmeticMatrix FMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 			matrix.getRowNameArray(), matrix.getColNameArray());
-		Matrix GMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+		ArithmeticMatrix GMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 			matrix.getRowNameArray(), matrix.getColNameArray());
-		FMatrix.MatrixCopy(getFMatrix());
-		GMatrix.MatrixCopy(getGMatrix());
+		FMatrix.matrixCopy(getFMatrix());
+		GMatrix.matrixCopy(getGMatrix());
 		return getCoherenceMatrix(FMatrix, GMatrix, alpha, beta);
 	}
 	
@@ -211,7 +246,7 @@ public class TaskSequence{
 * @return ҡޥȥꥯ
 * 
 */
-	private Matrix getCoherenceMatrix(Matrix FMatrix, Matrix GMatrix){
+	private ArithmeticMatrix getCoherenceMatrix(ArithmeticMatrix FMatrix, ArithmeticMatrix GMatrix){
 		return FMatrix.getAddMatrix(GMatrix);
 	}
 	
@@ -225,13 +260,13 @@ public class TaskSequence{
 * @return ҡޥȥꥯ
 * 
 */
-	private Matrix getCoherenceMatrix(Matrix FMatrix, Matrix GMatrix, double alpha, double beta){
-		Matrix Fm = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+	private ArithmeticMatrix getCoherenceMatrix(ArithmeticMatrix FMatrix, ArithmeticMatrix GMatrix, double alpha, double beta){
+		ArithmeticMatrix Fm = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 			matrix.getRowNameArray(), matrix.getColNameArray());
-		Matrix Gm = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+		ArithmeticMatrix Gm = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 			matrix.getRowNameArray(), matrix.getColNameArray());
-		Fm.MatrixCopy(FMatrix.getTimesMatrix(alpha));
-		Gm.MatrixCopy(GMatrix.getTimesMatrix(beta));
+		Fm.matrixCopy(FMatrix.getTimesMatrix(alpha));
+		Gm.matrixCopy(GMatrix.getTimesMatrix(beta));
 		return Fm.getAddMatrix(Gm);
 	}
 	
@@ -258,14 +293,14 @@ public class TaskSequence{
 		if(isNormalIndex(alpha, beta)){
 			
 			//ãޥȥꥯ
-			Matrix reachMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+			ArithmeticMatrix reachMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 				matrix.getRowNameArray(), matrix.getColNameArray());
-			reachMatrix.MatrixCopy(getReachMatrix(matrix));
+			reachMatrix.matrixCopy(getReachMatrix(matrix));
 			
 			//ҡޥȥꥯ
-			Matrix CMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength(),
+			ArithmeticMatrix CMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength(),
 				matrix.getRowNameArray(), matrix.getColNameArray());
-			CMatrix.MatrixCopy(getCoherenceMatrix(alpha, beta));
+			CMatrix.matrixCopy(getCoherenceMatrix(alpha, beta));
 			
 			//̤֤
 			int[] returnArray;
@@ -376,12 +411,13 @@ public class TaskSequence{
 	}
 	
 /**
-* ãޥȥꥯ¾ǤزãǤ뤬¾Ǥ餽ǤؤϲãǤϤʤǤõޤ
+* ¾ǤزãǤ뤬¾Ǥ餽ǤؤϲãǤϤʤǤãޥȥꥯõޤ
+* ʤǽܤõޤ
 * ̤ϥǿboolean֤ޤ
 * @param reachMatrix ãޥȥꥯ
 * @return ̤
 */
-	private boolean[] getReachElement(Matrix reachMatrix){
+	public boolean[] getReachElement(ArithmeticMatrix reachMatrix){
 		boolean[] returnArray = new boolean[reachMatrix.getRowLength()];
 		for(int i = 0; i < reachMatrix.getRowLength(); i++){
 			int count = 0;
@@ -409,7 +445,7 @@ public class TaskSequence{
 * @param coherenceMatrix ҡޥȥꥯ
 * @return 򤵤
 */
-	private int getItemNumber(int item, boolean[] choiceArray, Matrix coherenceMatrix){
+	private int getItemNumber(int item, boolean[] choiceArray, ArithmeticMatrix coherenceMatrix){
 		int itemNumber = 0;
 		double val = Double.NEGATIVE_INFINITY;
 		for(int i = 0; i < choiceArray.length; i++){
@@ -422,17 +458,33 @@ public class TaskSequence{
 		return itemNumber;
 	}
 	
+/**
+* եͤŬɤåޤ
+* @param alpha ե
+* @return ͤŬǤtrue
+*/
+	public boolean isNormalAlpha(double alpha){
+		return (0.0 <= Math.abs(alpha)) && (Math.abs(alpha) <= 1.0);
+	}
+	
+/**
+* ١ͤŬɤåޤ
+* @param beta ١
+* @return ͤŬǤtrue
+*/
+	public boolean isNormalBeta(double beta){
+		return (0.0 <= Math.abs(beta)) && (Math.abs(beta) <= 1.0);
+	}
+	
 /**
 * եȥ١ͤŬɤåޤ
 * @param alpha ե
 * @param beta ١
 * @return ͤŬǤtrue
 */
-	private boolean isNormalIndex(double alpha, double beta){
+	public boolean isNormalIndex(double alpha, double beta){
 		boolean condition = (Math.abs(alpha) + Math.abs(beta) == 1.0);
-		boolean condition2 = ((0.0 <= Math.abs(alpha)) && (Math.abs(alpha) <= 1.0));
-		boolean condition3 = ((0.0 <= Math.abs(beta)) && (Math.abs(beta) <= 1.0));
-		return condition && condition2 && condition3;
+		return condition && isNormalAlpha(alpha) && isNormalBeta(beta);
 	}
 	
 /**
@@ -440,10 +492,10 @@ public class TaskSequence{
 * @param adjacencyMatrix Ĵ٤ܥޥȥꥯ
 * @return ۹ܤɬפǤtrue
 */
-	private boolean needDummy(Matrix adjacencyMatrix){
-		Matrix RMatrix = new Matrix(adjacencyMatrix.getRowLength(), adjacencyMatrix.getColLength(),
+	private boolean needDummy(ArithmeticMatrix adjacencyMatrix){
+		ArithmeticMatrix RMatrix = new ArithmeticMatrix(adjacencyMatrix.getRowLength(), adjacencyMatrix.getColLength(),
 			adjacencyMatrix.getRowNameArray(), adjacencyMatrix.getColNameArray());
-		RMatrix.MatrixCopy(adjacencyMatrix.getReachMatrix());
+		RMatrix.matrixCopy(adjacencyMatrix.getReachMatrix());
 		
 		boolean[] el = new boolean[RMatrix.getRowLength()];
 		System.arraycopy(getReachElement(RMatrix), 0, el, 0, RMatrix.getRowLength());
@@ -463,9 +515,9 @@ public class TaskSequence{
 * @param m ꤹܥޥȥꥯ
 * @exception NotSquareMatrixException ܥޥȥꥯǤϤʤ
 */
-	public void setMatrix(Matrix m){
+	public void setMatrix(ArithmeticMatrix m){
 		if(m.isSquare()){
-		baseMatrix.MatrixCopy(m);
+		baseMatrix.matrixCopy(m);
 		setDummy();
 		}
 		else{
@@ -477,19 +529,19 @@ public class TaskSequence{
 * ۹ܤꤷޤ
 */
 	private void setDummy(){
-		matrix.MatrixCopy(baseMatrix);
+		matrix.matrixCopy(baseMatrix);
 		if(needDummy(baseMatrix)){
 			giveDummy = true;
 			matrix.reSizeMatrix(baseMatrix.getRowLength()+1, baseMatrix.getColLength()+1);
-			matrix.MatrixMove(0, 0, 1, 1, baseMatrix.getRowLength(), baseMatrix.getColLength());
+			matrix.matrixMove(0, 0, 1, 1, baseMatrix.getRowLength(), baseMatrix.getColLength());
 			matrix.rowNameMove(0, 1, baseMatrix.getRowLength());
 			matrix.colNameMove(0, 1, baseMatrix.getColLength());
 			matrix.setRowName(0, "Dummy");
 			matrix.setColName(0, "Dummy");
 			
-			Matrix RMatrix = new Matrix(baseMatrix.getRowLength(), baseMatrix.getColLength(),
+			ArithmeticMatrix RMatrix = new ArithmeticMatrix(baseMatrix.getRowLength(), baseMatrix.getColLength(),
 				baseMatrix.getRowNameArray(), baseMatrix.getColNameArray());
-			RMatrix.MatrixCopy(baseMatrix.getReachMatrix());
+			RMatrix.matrixCopy(baseMatrix.getReachMatrix());
 			
 			for(int i = 0; i < matrix.getColLength(); i++){
 				matrix.setCell(i, 0, TASK_SEQUENCE_FALSE);
@@ -525,8 +577,8 @@ public class TaskSequence{
 * @return 
 */
 	private int getRegular(){
-		Matrix reachMatrix = new Matrix();
-		reachMatrix.MatrixCopy(matrix.getReachMatrix());
+		ArithmeticMatrix reachMatrix = new ArithmeticMatrix();
+		reachMatrix.matrixCopy(matrix.getReachMatrix());
 		double max = 0.0;
 		int maxIndex = 0;
 		double count = 0.0;
